pub(crate) struct NodeActor {
name: String,
pub script_chan: GenericSender<DevtoolScriptControlMsg>,
pub pipeline: PipelineId,
pub walker: String,
pub style_rules: AtomicRefCell<HashMap<(String, usize), String>>,
}Fields
name: Stringscript_chan: GenericSender<DevtoolScriptControlMsg>pipeline: PipelineIdwalker: Stringstyle_rules: AtomicRefCell<HashMap<(String, usize), String>>Trait Implementations
Sourceimpl Actor for NodeActor
impl Actor for NodeActor
Sourcefn handle_message(
&self,
request: ClientRequest<'_, '_>,
registry: &ActorRegistry,
msg_type: &str,
msg: &Map<String, Value>,
_id: StreamId,
) -> Result<(), ActorError>
fn handle_message( &self, request: ClientRequest<'_, '_>, registry: &ActorRegistry, msg_type: &str, msg: &Map<String, Value>, _id: StreamId, ) -> Result<(), ActorError>
The node actor can handle the following messages:
-
modifyAttributes: Asks the script to change a value in the attribute of the corresponding node -
getUniqueSelector: Returns the display name of this node
fn name(&self) -> String
fn cleanup(&self, _id: StreamId)
Sourceimpl MallocSizeOf for NodeActor
impl MallocSizeOf for NodeActor
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.